@@ -144,15 +144,16 @@ DELEGATE_INFO_FORMATTER = {
 delegate_info_formatter = apply_formatters_to_dict(DELEGATE_INFO_FORMATTER)
 
 LOCKED_DELEGATE_INFO_FORMATTER = {
-    "Amount": to_integer_if_hex,
+    "Released": to_integer_if_hex,
+    "RestrictingPlan": to_integer_if_hex,
 }
 
 locked_delegate_info_formatter = apply_formatters_to_dict(LOCKED_DELEGATE_INFO_FORMATTER)
 
 DELEGATE_LOCK_INFO_FORMATTER = {
     "Locks": apply_list_to_array_formatter(locked_delegate_info_formatter),
-    "Balance": to_integer_if_hex,
-    "Restricting": to_integer_if_hex,
+    "Released": to_integer_if_hex,
+    "RestrictingPlan": to_integer_if_hex,
 }
 
 delegate_lock_info_formatter = apply_formatters_to_dict(DELEGATE_LOCK_INFO_FORMATTER)
